# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['src']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'subwhisper',
    'version': '0.1.0',
    'description': '',
    'long_description': "SubWhisper\n---------\n\nUse command for preload model\n```python\nfrom subwhisper import setup\n\nsetup()\n```\n\nUse command for transcribe audio\n```python\nfrom subwhisper import process\n\nprocess(file='/path/to/file')\n```\n",
    'author': 'tupiznak',
    'author_email': 'akej-vonavi@mail.ru',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



from typing import Literal, Any

from transformers import pipeline

whisper_types = Literal['tiny', 'small', 'base', 'medium', 'large-v2']


def whisper_pipeline(*, whisper: whisper_types = 'small', device: int = 0, batch_size: int = 4) -> pipeline:
    transcribe = pipeline(
        task="automatic-speech-recognition",
        model=f"openai/whisper-{whisper}",
        chunk_length_s=30,
        device=device,
        batch_size=batch_size
    )
    transcribe.model.config.forced_decoder_ids = transcribe.tokenizer.get_decoder_prompt_ids(
        language="russian",
        task="transcribe"
    )
    return transcribe


def setup(*, whisper: whisper_types = 'small', device: int = 0, batch_size: int = 4) -> None:
    whisper_pipeline(whisper=whisper, device=device, batch_size=batch_size)


def process(*, file: str = None, whisper: whisper_types = 'small', device: int = 0, batch_size: int = 4) \
        -> dict[str, list[dict[str, Any]]]:
    pipe = whisper_pipeline(whisper=whisper, device=device, batch_size=batch_size)
    transcribed_chunks = pipe(file, return_timestamps="word")['chunks']

    events = [
        {'tStartMs': int(chunk['timestamp'][0] * 1000),
         'segs': [{'utf8': chunk['text']}]}
        for chunk in transcribed_chunks
    ]
    json3 = {'events': events}
    return json3


if __name__ == '__main__':
    process()
